@@ -106,7 +106,7 @@ def reduce_depgraph(dg):
 
 # guarded imports, which don't need to be included in python-minimal
 excluded_imports = {
-    'argparse': set(('gettext', 'shutil')),
+    'argparse': set(('difflib', 'gettext', 'shutil')),
     'codecs': set(('encodings',)),
     'collections': set(('cPickle', 'pickle', 'doctest')),
     'compileall': set(('concurrent', 'multiprocessing')),
@@ -128,12 +128,12 @@ excluded_imports = {
     'reprlib': set(('_dummy_thread',)),
     'shutil': set(('bz2','lzma', 'tarfile', 'zipfile')),
     #'socket': set(('_ssl',)),
-    '_sitebuiltins': set(('_pyrepl', 'pydoc')),
+    '_sitebuiltins': set(('pydoc',)),
     'subprocess': set(('dummy_threading',)),
     'sysconfig': set(('pprint','_osx_support', '_aix_support')),
     'tempfile': set(('_dummy_thread', 'shutil')),
     'tokenize': set(('_tokenize',)),
-    'traceback': set(('_suggestions',)),
+    'traceback': set(('_suggestions', 'codeop')),
     'functools': set(('typing',)),
     'zipfile': set(('bz2','lzma')),
     'random': set(('statistics',)),
